==> Tridium_EMEA_N4_Supervisor-4.10.11.12.zip: rc/wb/util/UserPasswordEditor.js <==
function _slicedToArray(r, e) { return _arrayWithHoles(r) || _iterableToArrayLimit(r, e) || _unsupportedIterableToArray(r, e) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0; } }
function _arrayLikeToArray(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t["return"] && (u = t["return"](), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(r) { if (Array.isArray(r)) return r; }
/**
 * @copyright 2015 Tridium, Inc. All Rights Reserved.
 * @author Logan Byam
 */

/**
 * API Status: **Private**
 * @module nmodule/webEditors/rc/wb/util/UserPasswordEditor
 */
define(['baja!', 'baja!baja:PasswordCache,' + 'baja:PasswordAuthenticationScheme,baja:User,' + 'baja:AbsTime', 'jquery', 'Promise', 'underscore', 'nmodule/webEditors/rc/fe/baja/ConfirmPasswordEditor', 'nmodule/webEditors/rc/fe/baja/BaseEditor', 'nmodule/webEditors/rc/fe/baja/util/spaceUtils', 'nmodule/webEditors/rc/fe/baja/util/subscriberUtils', 'nmodule/webEditors/rc/servlets/password', 'lex!baja'], function (baja, types, $, Promise, _, ConfirmPasswordEditor, BaseEditor, spaceUtils, subscriberUtils, password, lexs) {
  'use strict';

  var resolveService = spaceUtils.resolveService,
    leaseWhenNeeded = subscriberUtils.leaseWhenNeeded,
    getAuthenticationSchemes = leaseWhenNeeded(function (base) {
      return resolveService('baja:AuthenticationService', base).then(function (authenticationService) {
        return authenticationService.get('authenticationSchemes');
      });
    }),
    SHOULD_VALIDATE = BaseEditor.SHOULD_VALIDATE;

  /** @param {String} err */
  function reject(err) {
    return Promise.reject(new Error(err));
  }
  function getPasswordConfig(user, base) {
    return getAuthenticationSchemes(base).then(function (authenticationSchemes) {
      var schemeName = user.get('authenticationSchemeName');
      //NCCB-18386
      return baja.Ord.make({
        base: authenticationSchemes.getNavOrd(),
        child: 'slot:' + schemeName + '/globalPasswordConfiguration'
      }).get({
        lease: true
      });
    });
  }

  /**
   * @class
   * @alias module:nmodule/webEditors/rc/wb/util/UserPasswordEditor
   * @extends module:nmodule/webEditors/rc/fe/baja/BaseEditor
   */
  var UserPasswordEditor = function UserPasswordEditor(params) {
    var that = this;
    ConfirmPasswordEditor.call(that, $.extend({}, {
      keyName: 'UserPasswordEditor'
    }, params));
  };
  UserPasswordEditor.prototype = Object.create(ConfirmPasswordEditor.prototype);
  UserPasswordEditor.prototype.constructor = UserPasswordEditor;

  /**
   * Get the `baja:User` the loaded password belongs to.
   *
   * @private
   * @returns {Promise} promise to be resolved with a `User`, or
   * rejected if the password does not belong to a
   * `baja:PasswordCache` that belongs to a `baja:User`.
   */
  UserPasswordEditor.prototype.$getUser = function () {
    var complex = this.getComplex();
    if (!complex) {
      return reject('UserPasswordEditor only works as a ComplexSlotEditor');
    }
    if (!baja.hasType(complex, 'baja:PasswordCache')) {
      return reject('password must belong to a PasswordCache');
    }
    var user = complex.getParent();
    if (!baja.hasType(user, 'baja:User')) {
      return reject('authenticator must belong to a User');
    }
    return Promise.resolve(user);
  };

  /**
   * Resolve the `baja:GlobalPasswordConfiguration` that applies to the backing
   * `User`, as configured by the `authenticationSchemeName` slot on the user.
   *
   * @private
   * @returns {Promise} promise to be resolved with the password config,
   * or rejected if it could not be found
   */
  UserPasswordEditor.prototype.$getPasswordConfig = function () {
    return Promise.all([this.$getUser(), this.getOrdBase()]).then(function (_ref) {
      var _ref2 = _slicedToArray(_ref, 2),
        user = _ref2[0],
        ordBase = _ref2[1];
      return getPasswordConfig(user, ordBase);
    });
  };

  /**
   * Does not actually load the password into the DOM. This only verifies that
   * the loaded password belongs to a `baja:User`; this means that in order
   * to function, this `UserPasswordEditor` must be instantiated as a
   * `ComplexSlotEditor`. The backing `Complex` instance *must* be a
   * `baja:PasswordCache` or subclass that belongs to a
   * `baja:User`.
   *
   * @param {baja.Simple} password
   * @returns {Promise} promise to be resolved if the password actually
   * is a `baja:Password` that correctly belongs to a `User`.
   */
  UserPasswordEditor.prototype.doLoad = function (password) {
    var that = this;
    if (!baja.hasType(password, 'baja:Password')) {
      return reject('baja:Password required');
    }
    return Promise.all([this.$getUser(), ConfirmPasswordEditor.prototype.doLoad.call(this, password)]).then(function (_ref3) {
      var _ref4 = _slicedToArray(_ref3, 1),
        user = _ref4[0];
      /**
       * when adding a new user, we want the password to always be validated.
       * when editing an existing user, we only want to validate the password
       * if it has been modified. since new users are not mounted yet, we set
       * shouldValidate accordingly, which will be respected by UserManager.
       */
      that.properties().add(SHOULD_VALIDATE, !user.isMounted());
    });
  };

  /**
   * Saving a `UserPasswordEditor` only makes sense when editing a password that
   * belongs to a User. Since BajaScript will not encode a `baja:Password`
   * (nor should it), the save operation will be delegated to the
   * `ChangeUserPasswordServlet` instead.
   *
   * @see module:nmodule/webEditors/rc/fe/baja/ComplexSlotEditor
   * @see module:nmodule/webEditors/rc/servlets/password
   * @returns {Promise}
   */
  UserPasswordEditor.prototype.saveToComplex = function (pw, params) {
    return Promise.all([this.$getUser(), this.getOrdBase()]).then(function (_ref5) {
      var _ref6 = _slicedToArray(_ref5, 2),
        user = _ref6[0],
        base = _ref6[1];
      return password.changePasswords([user.getName()], [pw.encodeToString()], base);
    });
  };
  return UserPasswordEditor;
});

==> Tridium_EMEA_N4_Supervisor-4.14.3.24.zip: rc/wb/util/UserPasswordEditor.js <==
function _slicedToArray(r, e) { return _arrayWithHoles(r) || _iterableToArrayLimit(r, e) || _unsupportedIterableToArray(r, e) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0; } }
function _arrayLikeToArray(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t["return"] && (u = t["return"](), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(r) { if (Array.isArray(r)) return r; }
/**
 * @copyright 2015 Tridium, Inc. All Rights Reserved.
 * @author Logan Byam
 */

/**
 * API Status: **Private**
 * @module nmodule/webEditors/rc/wb/util/UserPasswordEditor
 */
define(['baja!', 'baja!baja:PasswordCache,' + 'baja:PasswordAuthenticationScheme,baja:User,' + 'baja:AbsTime', 'jquery', 'Promise', 'underscore', 'nmodule/webEditors/rc/fe/baja/ConfirmPasswordEditor', 'nmodule/webEditors/rc/fe/baja/BaseEditor', 'nmodule/webEditors/rc/fe/baja/util/spaceUtils', 'nmodule/webEditors/rc/fe/baja/util/subscriberUtils', 'nmodule/webEditors/rc/servlets/password'], function (baja, types, $, Promise, _, ConfirmPasswordEditor, BaseEditor, spaceUtils, subscriberUtils, password) {
  'use strict';

  var resolveService = spaceUtils.resolveService,
    leaseWhenNeeded = subscriberUtils.leaseWhenNeeded,
    getAuthenticationSchemes = leaseWhenNeeded(function (base) {
      return resolveService('baja:AuthenticationService', base).then(function (authenticationService) {
        return authenticationService.get('authenticationSchemes');
      });
    }),
    SHOULD_VALIDATE = BaseEditor.SHOULD_VALIDATE;

  /** @param {String} err */
  function reject(err) {
    return Promise.reject(new Error(err));
  }
  function getPasswordConfig(user, base) {
    return getAuthenticationSchemes(base).then(function (authenticationSchemes) {
      var schemeName = user.get('authenticationSchemeName');
      //NCCB-18386
      return baja.Ord.make({
        base: authenticationSchemes.getNavOrd(),
        child: 'slot:' + schemeName + '/globalPasswordConfiguration'
      }).get({
        lease: true
      });
    });
  }

  /**
   * @class
   * @alias module:nmodule/webEditors/rc/wb/util/UserPasswordEditor
   * @extends module:nmodule/webEditors/rc/fe/baja/BaseEditor
   */
  var UserPasswordEditor = function UserPasswordEditor(params) {
    var that = this;
    ConfirmPasswordEditor.call(that, $.extend({}, {
      keyName: 'UserPasswordEditor'
    }, params));
  };
  UserPasswordEditor.prototype = Object.create(ConfirmPasswordEditor.prototype);
  UserPasswordEditor.prototype.constructor = UserPasswordEditor;

  /**
   * Get the `baja:User` the loaded password belongs to.
   *
   * @private
   * @returns {Promise} promise to be resolved with a `User`, or
   * rejected if the password does not belong to a
   * `baja:PasswordCache` that belongs to a `baja:User`.
   */
  UserPasswordEditor.prototype.$getUser = function () {
    var complex = this.getComplex();
    if (!complex) {
      return reject('UserPasswordEditor only works as a ComplexSlotEditor');
    }
    if (!baja.hasType(complex, 'baja:PasswordCache')) {
      return reject('password must belong to a PasswordCache');
    }
    var user = complex.getParent();
    if (!baja.hasType(user, 'baja:User')) {
      return reject('authenticator must belong to a User');
    }
    return Promise.resolve(user);
  };

  /**
   * Resolve the `baja:GlobalPasswordConfiguration` that applies to the backing
   * `User`, as configured by the `authenticationSchemeName` slot on the user.
   *
   * @private
   * @returns {Promise} promise to be resolved with the password config,
   * or rejected if it could not be found
   */
  UserPasswordEditor.prototype.$getPasswordConfig = function () {
    return Promise.all([this.$getUser(), this.getOrdBase()]).then(function (_ref) {
      var _ref2 = _slicedToArray(_ref, 2),
        user = _ref2[0],
        ordBase = _ref2[1];
      return getPasswordConfig(user, ordBase);
    });
  };

  /**
   * Does not actually load the password into the DOM. This only verifies that
   * the loaded password belongs to a `baja:User`; this means that in order
   * to function, this `UserPasswordEditor` must be instantiated as a
   * `ComplexSlotEditor`. The backing `Complex` instance *must* be a
   * `baja:PasswordCache` or subclass that belongs to a
   * `baja:User`.
   *
   * @param {baja.Simple} password
   * @returns {Promise} promise to be resolved if the password actually
   * is a `baja:Password` that correctly belongs to a `User`.
   */
  UserPasswordEditor.prototype.doLoad = function (password) {
    var that = this;
    if (!baja.hasType(password, 'baja:Password')) {
      return reject('baja:Password required');
    }
    return Promise.all([this.$getUser(), ConfirmPasswordEditor.prototype.doLoad.call(this, password)]).then(function (_ref3) {
      var _ref4 = _slicedToArray(_ref3, 1),
        user = _ref4[0];
      /**
       * when adding a new user, we want the password to always be validated.
       * when editing an existing user, we only want to validate the password
       * if it has been modified. since new users are not mounted yet, we set
       * shouldValidate accordingly, which will be respected by UserManager.
       */
      that.properties().add(SHOULD_VALIDATE, !user.isMounted());
    });
  };

  /**
   * Saving a `UserPasswordEditor` only makes sense when editing a password that
   * belongs to a User. Since BajaScript originally did not allow encoding a `baja:Password`,
   * the save operation delegates to the `BPasswordRpc`.
   * Starting in Niagara 4.14 the RPC is only called when the Complex being edited
   * is mounted.
   *
   * @see module:nmodule/webEditors/rc/fe/baja/ComplexSlotEditor
   * @see module:nmodule/webEditors/rc/servlets/password
   * @param {module:baja/obj/Password} pw
   * @returns {Promise|undefined}
   */
  UserPasswordEditor.prototype.saveToComplex = function (pw) {
    var complex = this.getComplex();
    if (!complex.isMounted()) {
      return;
    }
    return Promise.all([this.$getUser(), this.getOrdBase()]).then(function (_ref5) {
      var _ref6 = _slicedToArray(_ref5, 2),
        user = _ref6[0],
        base = _ref6[1];
      return password.changePasswords([user.getName()], [pw.encodeToString()], base);
    });
  };
  return UserPasswordEditor;
});
